using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Blazorise;
using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using UserService.Infrastructure;
using UserService.Infrastructure.DataModels;

namespace UserService.Pages
{
    public abstract class MembersBase<T> : ComponentBase where T : Member
    {
        protected IReadOnlyList<OrganizationUnit>? OrganizationUnits { get; set; }

        protected IReadOnlyList<T>? Members { get; set; }

        protected string? CustomFilterValue { get; set; }

        protected abstract Task RowInsertingCallback(CancellableRowChange<T, Dictionary<string, object>> arg);

        protected abstract Task RowInsertedCallback(SavedRowItem<T, Dictionary<string, object>> arg);
        protected abstract Task RowDeletingCallback(CancellableRowChange<T> arg);
        protected abstract Task RowUpdatingCallback(CancellableRowChange<T, Dictionary<string, object>> arg);
        protected abstract bool OnCustomFilter(T model);

        protected void ValidateCommonName(ValidatorEventArgs e)
        {
            if (e == null) throw new ArgumentNullException(nameof(e));
            var commonName = e.Value?.ToString();
            var validationResult = Validators.ValidateCommonName(commonName, Members ?? Enumerable.Empty<Member>());
            e.Status = validationResult == false ? ValidationStatus.Error : ValidationStatus.Success;
        }
    }
}